@@ -25,7 +25,7 @@ protected:
     void paintEvent(QPaintEvent *event) override;
 
 private:
-    bool mResultFailed;
+    bool mResultFailed = false;
 };
 
 /**
@@ -66,7 +66,7 @@ public Q_SLOTS:
     void slotTranslate();
     void slotCloseWidget();
 
-private Q_SLOTS:
+private:
     void slotFromLanguageChanged(int, bool initialize = false);
     void slotTextChanged();
     void slotInvertLanguage();
@@ -85,8 +85,9 @@ Q_SIGNALS:
 private:
     void init();
     void initLanguage();
+    void switchEngine();
+    void loadEngineSettings();
     class TranslatorWidgetPrivate;
     std::unique_ptr<TranslatorWidgetPrivate> const d;
 };
 }
-
